severity = 1
include = Moose::ProhibitMultipleWiths Moose::ProhibitNewMethod Moose::RequireCleanNamespace Moose::RequireMakeImmutable
color = 1
verbose = 9

[BuiltinFunctions::ProhibitStringyEval]
allow_includes = 1

[CodeLayout::ProhibitTrailingWhitespace]

[-CodeLayout::RequireTidyCode]

[-CodeLayout::RequireASCII]

[-CodeLayout::ProhibitHashBarewords]

[-Compatibility::PodMinimumVersion]

[-Documentation::RequirePodSections]

[-Documentation::RequirePODUseEncodingUTF8]

[-Miscellanea::ProhibitUselessNoCritic]

[-Miscellanea::RequireRcsKeywords]

[-Modules::RequireExplicitPackage]

[-Editor::RequireEmacsFileVariables]

[Lax::RequireExplicitPackage::ExceptForPragmata]
allowed_pragmata = strict warnings utf8 perlversion

[Documentation::PodSpelling]
spell_command = aspell list --lang en_US
stop_words = metadata KiokuDB KENTNL KENTNL's DZil plugin

[Subroutines::ProhibitUnusedPrivateSubroutines]
private_name_regex = _(?!build_)\w

[TestingAndDebugging::RequireUseStrict]
equivalent_modules = Moose

[TestingAndDebugging::RequireUseWarnings]
equivalent_modules = Moose

[Tics::ProhibitLongLines]
base_max = 130









